==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/Tree.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { TreeSelection_$type } from "./TreeSelection";
import { Direction_$type } from "./Direction";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { TreeSelectionOptionsEventArgs } from "./TreeSelectionOptionsEventArgs";
import { TreeItemComponentEventArgs } from "./TreeItemComponentEventArgs";
/**
 * @hidden
 */
var Tree = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Tree, _super);
    function Tree() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.j = new WCNativeHelper();
        _this.m = null;
        _this.selectionChanged = null;
        _this.itemExpanding = null;
        _this.itemExpanded = null;
        _this.itemCollapsing = null;
        _this.itemCollapsed = null;
        _this.activeItem = null;
        return _this;
    }
    Object.defineProperty(Tree.prototype, "k", {
        get: function () {
            return this.j;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Tree.prototype, "nativeElement", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            this.m = a;
            this.j.n = this.m;
        },
        enumerable: false,
        configurable: true
    });
    Tree.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Tree.prototype, "l", {
        get: function () {
            var ret_ = this.k.m("singleBranchExpand");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.k.u("singleBranchExpand", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Tree.prototype, "h", {
        get: function () {
            var ret_ = this.k.m("selection");
            ret_ = enumGetBox(TreeSelection_$type, EnumUtil.getEnumValue(TreeSelection_$type, this.k.f(TreeSelection_$type, ret_)));
            return EnumUtil.getEnumValue(TreeSelection_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(TreeSelection_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.k.u("selection", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Tree.prototype, "a", {
        get: function () {
            var ret_ = this.k.m("dir");
            ret_ = enumGetBox(Direction_$type, EnumUtil.getEnumValue(Direction_$type, this.k.f(Direction_$type, ret_)));
            return EnumUtil.getEnumValue(Direction_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(Direction_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.k.u("dir", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Tree.prototype, "b", {
        get: function () {
            var ret_ = this.k.m("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.k.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.k.u("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    Tree.prototype.selectionChangedChanged = function () {
        var _this = this;
        if (this.selectionChanged != null) {
            this.k.q("selection", function (a) { return _this.selectionChanged(_this, TreeSelectionOptionsEventArgs.a(a)); });
        }
        else {
            this.k.t("selection");
        }
    };
    Tree.prototype.itemExpandingChanged = function () {
        var _this = this;
        if (this.itemExpanding != null) {
            this.k.q("itemExpanding", function (a) { return _this.itemExpanding(_this, TreeItemComponentEventArgs.b(a)); });
        }
        else {
            this.k.t("itemExpanding");
        }
    };
    Tree.prototype.itemExpandedChanged = function () {
        var _this = this;
        if (this.itemExpanded != null) {
            this.k.q("itemExpanded", function (a) { return _this.itemExpanded(_this, TreeItemComponentEventArgs.b(a)); });
        }
        else {
            this.k.t("itemExpanded");
        }
    };
    Tree.prototype.itemCollapsingChanged = function () {
        var _this = this;
        if (this.itemCollapsing != null) {
            this.k.q("itemCollapsing", function (a) { return _this.itemCollapsing(_this, TreeItemComponentEventArgs.b(a)); });
        }
        else {
            this.k.t("itemCollapsing");
        }
    };
    Tree.prototype.itemCollapsedChanged = function () {
        var _this = this;
        if (this.itemCollapsed != null) {
            this.k.q("itemCollapsed", function (a) { return _this.itemCollapsed(_this, TreeItemComponentEventArgs.b(a)); });
        }
        else {
            this.k.t("itemCollapsed");
        }
    };
    Tree.prototype.activeItemChanged = function () {
        var _this = this;
        if (this.activeItem != null) {
            this.k.q("activeItem", function (a) { return _this.activeItem(_this, TreeItemComponentEventArgs.b(a)); });
        }
        else {
            this.k.t("activeItem");
        }
    };
    Tree.prototype.p = function () {
        this.nativeElement.connectedCallback();
    };
    Tree.prototype.q = function (a) {
        this.nativeElement.expandToItem(this.k.h(a));
    };
    Tree.$t = markType(Tree, 'Tree', BaseElement.$);
    return Tree;
}(BaseElement));
export { Tree };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/Tree.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { TreeSelection_$type } from "./TreeSelection";
import { Direction_$type } from "./Direction";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { TreeSelectionOptionsEventArgs } from "./TreeSelectionOptionsEventArgs";
import { TreeItemComponentEventArgs } from "./TreeItemComponentEventArgs";
/**
 * @hidden
 */
var Tree = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Tree, _super);
    function Tree() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.j = new WCNativeHelper();
        _this.m = null;
        _this.selectionChanged = null;
        _this.itemExpanding = null;
        _this.itemExpanded = null;
        _this.itemCollapsing = null;
        _this.itemCollapsed = null;
        _this.activeItem = null;
        return _this;
    }
    Object.defineProperty(Tree.prototype, "k", {
        get: function () {
            return this.j;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Tree.prototype, "nativeElement", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            this.m = a;
            this.j.o = this.m;
        },
        enumerable: false,
        configurable: true
    });
    Tree.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Tree.prototype, "l", {
        get: function () {
            var ret_ = this.k.n("singleBranchExpand");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.k.v("singleBranchExpand", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Tree.prototype, "h", {
        get: function () {
            var ret_ = this.k.n("selection");
            ret_ = enumGetBox(TreeSelection_$type, EnumUtil.getEnumValue(TreeSelection_$type, this.k.f(TreeSelection_$type, ret_)));
            return EnumUtil.getEnumValue(TreeSelection_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(TreeSelection_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.k.v("selection", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Tree.prototype, "a", {
        get: function () {
            var ret_ = this.k.n("dir");
            ret_ = enumGetBox(Direction_$type, EnumUtil.getEnumValue(Direction_$type, this.k.f(Direction_$type, ret_)));
            return EnumUtil.getEnumValue(Direction_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(Direction_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.k.v("dir", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Tree.prototype, "b", {
        get: function () {
            var ret_ = this.k.n("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.k.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.k.v("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    Tree.prototype.selectionChangedChanged = function () {
        var _this = this;
        if (this.selectionChanged != null) {
            this.k.r("selection", function (a) { return _this.selectionChanged(_this, TreeSelectionOptionsEventArgs.a(a)); });
        }
        else {
            this.k.u("selection");
        }
    };
    Tree.prototype.itemExpandingChanged = function () {
        var _this = this;
        if (this.itemExpanding != null) {
            this.k.r("itemExpanding", function (a) { return _this.itemExpanding(_this, TreeItemComponentEventArgs.b(a)); });
        }
        else {
            this.k.u("itemExpanding");
        }
    };
    Tree.prototype.itemExpandedChanged = function () {
        var _this = this;
        if (this.itemExpanded != null) {
            this.k.r("itemExpanded", function (a) { return _this.itemExpanded(_this, TreeItemComponentEventArgs.b(a)); });
        }
        else {
            this.k.u("itemExpanded");
        }
    };
    Tree.prototype.itemCollapsingChanged = function () {
        var _this = this;
        if (this.itemCollapsing != null) {
            this.k.r("itemCollapsing", function (a) { return _this.itemCollapsing(_this, TreeItemComponentEventArgs.b(a)); });
        }
        else {
            this.k.u("itemCollapsing");
        }
    };
    Tree.prototype.itemCollapsedChanged = function () {
        var _this = this;
        if (this.itemCollapsed != null) {
            this.k.r("itemCollapsed", function (a) { return _this.itemCollapsed(_this, TreeItemComponentEventArgs.b(a)); });
        }
        else {
            this.k.u("itemCollapsed");
        }
    };
    Tree.prototype.activeItemChanged = function () {
        var _this = this;
        if (this.activeItem != null) {
            this.k.r("activeItem", function (a) { return _this.activeItem(_this, TreeItemComponentEventArgs.b(a)); });
        }
        else {
            this.k.u("activeItem");
        }
    };
    Tree.prototype.p = function () {
        this.nativeElement.connectedCallback();
    };
    Tree.prototype.q = function (a) {
        this.nativeElement.expandToItem(this.k.i(a));
    };
    Tree.$t = markType(Tree, 'Tree', BaseElement.$);
    return Tree;
}(BaseElement));
export { Tree };
